%define vers 3.6.1
# This spec is really maintained only for RHEL 3 & 4 at this time. 
#  Building on Fedora is only an afterthought, and Red Hat 7 or 9 has
#  not be tested and won't work with the attempt below to gather the
#  release info at buildtime.
#
# comment the line below if you have CentOS, Fedora Core, or another OS
#%define rel %(if [ -f /etc/redhat-release ]; then cat /etc/redhat-release | cut -d' ' -f7 | cut -d'.' -f1; fi)

# uncomment the line below and add a leading "%" to try to gather the 
#  version of CentOS
%define rel %(if [ -f /etc/redhat-release ]; then cat /etc/redhat-release | cut -d' ' -f3 | cut -d'.' -f1; fi)

# uncomment the line below and add a leading "%" to try to gather the 
#  version of FC
#define rel %(if [ -f /etc/fedora-release ]; then cat /etc/fedora-release | cut -d' ' -f4; fi)

Summary: WebAuth authentication module for the Apache 2.x web servers.
Name: webauth
Version: %{vers}
# set the appropriate release if possible
# Change the "EL" portion of the release below if you want.
Release: 1.EL%{rel}
Group: System Environment/Daemons
URL: http://webauth.stanford.edu
Source: http://webauth.stanford.edu/dist/webauth-%{vers}.tar.gz
Patch0: webauth.load.i386.diff
Patch1: webauth.load.x86_64.diff
License: Stanford BSD-Style
BuildRoot: /var/tmp/%{name}-buildroot
BuildPrereq: httpd-devel >= 2.0.40-11, openssl-devel >= 0.9.7, e2fsprogs-devel, krb5-devel, curl-devel
Requires: httpd >= 2.0.40
Requires: mod_ssl
Requires: cyrus-sasl-gssapi
Requires: curl
Provides: mod_webauth.so
BuildRequires: libtool
BuildRequires: openldap-devel
BuildConflicts: krb5-SU

# RHEL 3 Stanford only fix below. You can replace with a different, but 
#  newer curl  & openssl package than rhel supplies and it will probably work. 
# You will have to change the release the test below to match your Fedora 
#  Core version (for fc1 & fc2 only I think).
%if %{rel} == 3
BuildRequires: krb5-SU
Requires: krb5-SU
Requires: curl-SU >= 7.15.3
BuildRequires: curl-SU >= 7.15.3
BuildRequires: openssl-SU >= 0.9.7
Requires: openssl-SU >= 0.9.7
Requires: openldap-SU >= 2.1.0
BuildRequires: openldap-SU >= 2.1.0
%endif

%ifarch i386
BuildArch: i686
%endif

%description
WebAuth is an authentication system for web pages and web applications. The 
first time a user attempts to access a web page protected by WebAuth, they will 
be sent to a central login server (weblogin.stanford.edu at Stanford) and 
prompted to authenticate. Normally, they will be asked for a username and 
password, although other authentication methods are possible. Once the user has 
logged in, the weblogin server will send their encrypted identity back to the 
original web page they were trying to access. Their identity will also be stored
in a cookie set by the weblogin server and they will not need to authenticate 
again until their credentials expire, even if they visit multiple protected web 
sites.


%prep
%setup -q 
# patch for either x86_64 or i386
%ifarch x86_64
%patch1
%else
%patch0
%endif

%build
./configure --with-kerberos=/usr/local --with-openssl=/usr/local --with-curl=/usr/local --with-apache=/usr --with-apxs=/usr/sbin/apxs 
LD_RUN_PATH=/usr/local/lib make 

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
%ifarch x86_64
%define _libdir /usr/lib64
%endif

mkdir -p $RPM_BUILD_ROOT%{_libdir}/httpd/modules
install -m 755 lib/.libs/libwebauth.so.1.2.0 $RPM_BUILD_ROOT%{_libdir}

install -m 755 modules/webauthldap/.libs/mod_webauthldap.so $RPM_BUILD_ROOT%{_libdir}/httpd/modules
install -m 755 modules/webauth/.libs/mod_webauth.so $RPM_BUILD_ROOT%{_libdir}/httpd/modules

ln -sf libwebauth.so.1.2.0 $RPM_BUILD_ROOT%{_libdir}/libwebauth.so
ln -sf libwebauth.so.1.2.0 $RPM_BUILD_ROOT%{_libdir}/libwebauth.so.1

mkdir -p $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT/usr/share/man/man1/
install -m 755 tools/wa_keyring $RPM_BUILD_ROOT%{_bindir}
install -m 644 tools/wa_keyring.1 $RPM_BUILD_ROOT/usr/share/man/man1/wa_keyring.1
gzip $RPM_BUILD_ROOT/usr/share/man/man1/wa_keyring.1


mkdir -p $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}
install -m 644 INSTALL $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}
install -m 644 README $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}/README
install -m 644 NEWS $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}
cp -rp docs $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}
cp -rp conf $RPM_BUILD_ROOT/$RPM_DOC_DIR/webauth-%{vers}

mkdir -p $RPM_BUILD_ROOT/etc/httpd/conf.d
cp -rp conf/debian/webauth.conf $RPM_BUILD_ROOT/etc/httpd/conf.d/
cp -rp conf/debian/webauth.load $RPM_BUILD_ROOT/etc/httpd/conf.d/webauth-load.conf
cp -rp conf/debian/webauthldap.conf $RPM_BUILD_ROOT/etc/httpd/conf.d/
cp -rp conf/debian/webauthldap.load $RPM_BUILD_ROOT/etc/httpd/conf.d/webauthldap-load.conf
mkdir -p $RPM_BUILD_ROOT/etc/webauth/
mkdir -p $RPM_BUILD_ROOT/var/lib/webauth/

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_libdir}/httpd/modules/*
%{_libdir}/libweb*
%{_bindir}/wa_keyring
%config /etc/httpd/conf.d/*
%doc %{_docdir}/webauth-%{vers}
%doc /usr/share/man/man1/wa_keyring.1*
%dir /etc/webauth
%defattr(-,root,apache,0770)
%dir /var/lib/webauth

%post
service httpd condrestart

%postun 
service httpd condrestart

%changelog
* Thu Jul 16 2009  Darren Patterson <darrenp1@stanford.edu> 3.6.1-1
- built 3.6.1

* Fri Jun 13 2008 Darren Patterson <darrenp1@stanford.edu> 3.6.0-2
- rebuild without krb5-SU

* Wed Apr 2 2008 Darren Patterson <darrenp1@stanford.edu> 3.6.0-1
- updated to 3.6.0.

* Mon May 7 2007 Darren Patterson <darrenp1@stanford.edu> 3.5.4-1
- update to 3.5.4

* Wed Apr 4 2007 Darren Patterson <darrenp1@stanford.edu> 3.5.3-2
- Substantial changes to use configuration as similar to deb as possible.
- Stanford users will now need the stanford-server RPM.

* Thu Oct 5 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.3-1
- updated for 3.5.3

* Tue Sep 12 2006 Digant C Kasundra <digant@stanford.edu> 3.5.1-4
- Moved stanford-webauth.conf back into the httpd conf.d dir to match the behavior of the debian package

* Thu Jun 28 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.1-3
- Changed rhel3 requirements to include openldap

* Thu Jun 12 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.1-2
- Made an attempt to support fedora core and added comments for users who may want to try and change/update the spec later to fix FC/CentOS(/other OS?) build issues.
- Moved stanford-webauth.conf to doc dir instead of httpd conf.d dir.

* Wed Jun 11 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.1-1
- updated release for 64-bit fixes 

* Wed May 31 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.0-2
- removed configure option that made rhel3 balk 

* Tue May 30 2006 Darren Patterson <darrenp1@stanford.edu> 
- added rel option for different rhel releases

* Mon May 22 2006 Darren Patterson <darrenp1@stanford.edu> 
- changed httpd restart to "condrestart"

* Fri May 19 2006 Darren Patterson <darrenp1@stanford.edu> 3.5.0
- updated to latest release
- removed module *.la and *.a files because they are extraneous.
- changed README to install as README instead of LICENSE

* Thu Apr 14 2005 Joe Little <jlittle@stanford.edu> 3.2.4-2
- fixed inclusion of default configs

* Thu Mar 10 2005 Joe Little <jlittle@stanford.edu> 3.2.4-1
- fixed webauthldap/webauth mod builds
- fixed library versioning of symlinks
- still lacks webkdc build

* Tue Apr  1 2003 Joe Little <jlittle@stanford.edu> 3.0.0-1
- first build
- enable-perl is not used; no perl bindings packaged
